=== modified file 'NEWS'
--- NEWS	2010-08-24 21:59:21 +0000
+++ NEWS	2010-08-25 02:16:31 +0000
@@ -61,6 +61,9 @@
   ``bzr launchpad-login user && bzr push lp:~/project/branch`` will now
   push to ``lp:~user/project/branch``.  (John Arbash Meinel)
 
+* New development format ``development8-subtree`` which is similar to the 
+  ``2a`` format and adds subtree support. (Jelmer Vernooij)
+
 Bug Fixes
 *********
 

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2010-08-23 20:37:18 +0000
+++ bzrlib/bzrdir.py	2010-08-25 02:16:31 +0000
@@ -3290,8 +3290,24 @@
     alias=True,
     hidden=True,
     )
+register_metadir(controldir.format_registry, 'development5-subtree',
+    'bzrlib.repofmt.pack_repo.RepositoryFormatPackDevelopment2Subtree',
+    help='Development format, subtree variant. Can convert data to and '
+        'from pack-0.92-subtree (and anything compatible with '
+        'pack-0.92-subtree) format repositories. Repositories and branches in '
+        'this format can only be read by bzr.dev. Please read '
+        'http://doc.bazaar.canonical.com/latest/developers/development-repo.html '
+        'before use.',
+    branch_format='bzrlib.branch.BzrBranchFormat7',
+    tree_format='bzrlib.workingtree.WorkingTreeFormat6',
+    experimental=True,
+    hidden=True,
+    alias=False,
+    )
+
+
 register_metadir(controldir.format_registry, 'development-subtree',
-    'bzrlib.repofmt.pack_repo.RepositoryFormatPackDevelopment2Subtree',
+    'bzrlib.repofmt.groupcompress_repo.RepositoryFormat2aSubtree',
     help='Current development format, subtree variant. Can convert data to and '
         'from pack-0.92-subtree (and anything compatible with '
         'pack-0.92-subtree) format repositories. Repositories and branches in '
@@ -3341,7 +3357,7 @@
         # 'rich roots. Supported by bzr 1.16 and later.',
     branch_format='bzrlib.branch.BzrBranchFormat7',
     tree_format='bzrlib.workingtree.WorkingTreeFormat6',
-    experimental=True,
+    experimental=False,
     )
 
 # The following format should be an alias for the rich root equivalent 

=== modified file 'bzrlib/repofmt/groupcompress_repo.py'
--- bzrlib/repofmt/groupcompress_repo.py	2010-08-11 06:14:09 +0000
+++ bzrlib/repofmt/groupcompress_repo.py	2010-08-25 02:16:31 +0000
@@ -1428,3 +1428,28 @@
         """See RepositoryFormat.get_format_description()."""
         return ("Repository format 2a - rich roots, group compression"
             " and chk inventories")
+
+
+class RepositoryFormat2aSubtree(RepositoryFormat2a):
+    """A 2a repository format that supports nested trees.
+
+    """
+
+    def _get_matching_bzrdir(self):
+        return bzrdir.format_registry.make_bzrdir('development-subtree')
+
+    def _ignore_setting_bzrdir(self, format):
+        pass
+
+    _matchingbzrdir = property(_get_matching_bzrdir, _ignore_setting_bzrdir)
+
+    def get_format_string(self):
+        return ('Bazaar development format 8\n')
+
+    def get_format_description(self):
+        """See RepositoryFormat.get_format_description()."""
+        return ("Development repository format 8 - nested trees, "
+                "group compression and chk inventories")
+
+    experimental = True
+    supports_tree_reference = True

=== modified file 'bzrlib/repofmt/pack_repo.py'
--- bzrlib/repofmt/pack_repo.py	2010-05-11 08:36:16 +0000
+++ bzrlib/repofmt/pack_repo.py	2010-08-25 02:16:31 +0000
@@ -2916,7 +2916,7 @@
 
     def _get_matching_bzrdir(self):
         return bzrdir.format_registry.make_bzrdir(
-            'development-subtree')
+            'development5-subtree')
 
     def _ignore_setting_bzrdir(self, format):
         pass

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2010-08-17 22:24:01 +0000
+++ bzrlib/repository.py	2010-08-25 02:16:31 +0000
@@ -3389,6 +3389,11 @@
     'bzrlib.repofmt.groupcompress_repo',
     'RepositoryFormat2a',
     )
+format_registry.register_lazy(
+    'Bazaar development format 8\n',
+    'bzrlib.repofmt.groupcompress_repo',
+    'RepositoryFormat2aSubtree',
+    )
 
 
 class InterRepository(InterObject):

